@@ -1,6 +1,7 @@
-from urllib.request import urlopen
 import socket
 from contextlib import contextmanager
+from urllib.request import urlopen
+
 import vcr
 
 
@@ -27,9 +28,9 @@ def test_ignore_localhost(tmpdir, httpbin):
     with overridden_dns({"httpbin.org": "127.0.0.1"}):
         cass_file = str(tmpdir.join("filter_qs.yaml"))
         with vcr.use_cassette(cass_file, ignore_localhost=True) as cass:
-            urlopen("http://localhost:{}/".format(httpbin.port))
+            urlopen(f"http://localhost:{httpbin.port}/")
             assert len(cass) == 0
-            urlopen("http://httpbin.org:{}/".format(httpbin.port))
+            urlopen(f"http://httpbin.org:{httpbin.port}/")
             assert len(cass) == 1
 
 
@@ -37,9 +38,9 @@ def test_ignore_httpbin(tmpdir, httpbin):
     with overridden_dns({"httpbin.org": "127.0.0.1"}):
         cass_file = str(tmpdir.join("filter_qs.yaml"))
         with vcr.use_cassette(cass_file, ignore_hosts=["httpbin.org"]) as cass:
-            urlopen("http://httpbin.org:{}/".format(httpbin.port))
+            urlopen(f"http://httpbin.org:{httpbin.port}/")
             assert len(cass) == 0
-            urlopen("http://localhost:{}/".format(httpbin.port))
+            urlopen(f"http://localhost:{httpbin.port}/")
             assert len(cass) == 1
 
 
@@ -47,8 +48,8 @@ def test_ignore_localhost_and_httpbin(tmpdir, httpbin):
     with overridden_dns({"httpbin.org": "127.0.0.1"}):
         cass_file = str(tmpdir.join("filter_qs.yaml"))
         with vcr.use_cassette(cass_file, ignore_hosts=["httpbin.org"], ignore_localhost=True) as cass:
-            urlopen("http://httpbin.org:{}".format(httpbin.port))
-            urlopen("http://localhost:{}".format(httpbin.port))
+            urlopen(f"http://httpbin.org:{httpbin.port}")
+            urlopen(f"http://localhost:{httpbin.port}")
             assert len(cass) == 0
 
 
@@ -56,12 +57,12 @@ def test_ignore_localhost_twice(tmpdir, httpbin):
     with overridden_dns({"httpbin.org": "127.0.0.1"}):
         cass_file = str(tmpdir.join("filter_qs.yaml"))
         with vcr.use_cassette(cass_file, ignore_localhost=True) as cass:
-            urlopen("http://localhost:{}".format(httpbin.port))
+            urlopen(f"http://localhost:{httpbin.port}")
             assert len(cass) == 0
-            urlopen("http://httpbin.org:{}".format(httpbin.port))
+            urlopen(f"http://httpbin.org:{httpbin.port}")
             assert len(cass) == 1
         with vcr.use_cassette(cass_file, ignore_localhost=True) as cass:
             assert len(cass) == 1
-            urlopen("http://localhost:{}".format(httpbin.port))
-            urlopen("http://httpbin.org:{}".format(httpbin.port))
+            urlopen(f"http://localhost:{httpbin.port}")
+            urlopen(f"http://httpbin.org:{httpbin.port}")
             assert len(cass) == 1
