@@ -1,32 +1,31 @@
-# -*- encoding: utf-8 -*-
 from unittest import mock
 
 import pytest
 
 from vcr.request import Request
 from vcr.serialize import deserialize, serialize
-from vcr.serializers import yamlserializer, jsonserializer, compat
+from vcr.serializers import compat, jsonserializer, yamlserializer
 
 
 def test_deserialize_old_yaml_cassette():
-    with open("tests/fixtures/migration/old_cassette.yaml", "r") as f:
+    with open("tests/fixtures/migration/old_cassette.yaml") as f:
         with pytest.raises(ValueError):
             deserialize(f.read(), yamlserializer)
 
 
 def test_deserialize_old_json_cassette():
-    with open("tests/fixtures/migration/old_cassette.json", "r") as f:
+    with open("tests/fixtures/migration/old_cassette.json") as f:
         with pytest.raises(ValueError):
             deserialize(f.read(), jsonserializer)
 
 
 def test_deserialize_new_yaml_cassette():
-    with open("tests/fixtures/migration/new_cassette.yaml", "r") as f:
+    with open("tests/fixtures/migration/new_cassette.yaml") as f:
         deserialize(f.read(), yamlserializer)
 
 
 def test_deserialize_new_json_cassette():
-    with open("tests/fixtures/migration/new_cassette.json", "r") as f:
+    with open("tests/fixtures/migration/new_cassette.json") as f:
         deserialize(f.read(), jsonserializer)
 
 
